==> element-ui-0.2.5.tgz: package/CHANGELOG.md <==
## 更新日志

### 0.2.4

`2016-09-10`

- 修复 Select 选中 value 为 0 的值时绑定值不更新的问题
- 修复 Select 多选时选项变为空数组后 placeholder 不出现的问题
- 修复 Table 中被固定列的高度不与其他列的高度协调的问题

### 0.2.3

`2016-08-30`

- 修复带多选的 Table 在数据更新后无法选中的问题
- 修复 Input-Number 的小数计算问题
- Checkbox `label` 的值不再限定只能是 string 类型，可以是 object 或者 number。

### 0.2.2

`2016-08-08`

- input-number 无法直接修改值的问题
- 修复 DatePicker 在 Form 中的显示问题
- 修复可清空的单选 Select 在点击清空按钮后 value 值不变的问题
- 为 Switch 添加 change 事件，在其值改变时触发
- 为 TableColumn 添加 show-tooltip-when-overflow 属性
- 修复 menu 的 activeKey 绑定值直接改变后无法触发菜单激活的问题

### 0.2.1

`2016-07-29`

- 修复 Dialog 内容超出时无法显示的问题

### 0.2.0

`2016-07-29`

- 增加 grid 相关组件
- form-item 增加 required 属性
- dropdown 组件增加下拉菜单水平对齐方向的属性
- form 组件增加 label-align,label-width,label-suffix属性
- form 组件实例方法增加 validateField(prop, cb) 方法对单个表单项进行验证

*非兼容性更新*

- progress 的 percentage 属性值范围从 0～1 改变为 1~100.
- input,input-number,autocomplete,select,checkbox,radio 组件的 model 属性改为 value
- checkbox,radio 组件的 value 属性改为 label
- form 组件的 models 属性改为 model

### 0.1.9

`2016-07-12`

- 增加 menu 组件

*非兼容性更新*

- 使用了新的图标集，原有的某些图标可能不存在了

### 0.1.8

`2016-07-07`

- dropdown 和 tooltip 首次出现闪动问题

### 0.1.7

`2016-07-06`

- dropdown 增加触发下拉菜单方式的参数
- 修正若干组件的样式问题和浏览器兼容问题
- 修复 popper.js 产生的过多 scroll 事件绑定
- 在 radio-group 里增加 radio-button 类型
- 为 select 添加 singleCancelable 选项

### 0.1.6

`2016-06-30`
- dropdown-menu 改为动态创建
- 修复 textarea 缺失 model 参数的 bug
- 修复 pagination 和 input-group 在 safari 下的样式问题

### 0.1.5

`2016-06-29`
- 为 MessageBox 和 Notification 注册全局方法
- button 的 loading 状态时改为不触发 hover 和点击等操作
- input组件 增加 maxlength 和 minlength 属性支持

### 0.1.4

`2016-06-29`

- 增加 Tabs、Form、MessageBox、Alert、Notification、Slider 组件
- dropdown menu 现在是直接插入到 body 节点下，并且修正了自适应宽度的 bug
- dropdown item 点击后关闭 dropdown menu
- radio 绑定值增加 Number 类型支持
- 增加 radio-group 组件
- 增加 checkbox-group 组件
- Select 组件 API 更新，现在的用法和原生 select 标签更加相似

==> element-ui-0.2.6.tgz: package/CHANGELOG.md <==
## 更新日志

### 0.2.6

`2016-09-22`

- 修复 在 ready 钩子函数中改变 Select 绑定值不生效的问题
- 修复 在多个依次出现的 Dialog 或 Message Box 全部关闭后页面有几率不可滚动的问题
- 新增 autocomplete 增加 select 事件

### 0.2.4

`2016-09-10`

- 修复 Select 选中 value 为 0 的值时绑定值不更新的问题
- 修复 Select 多选时选项变为空数组后 placeholder 不出现的问题
- 修复 Table 中被固定列的高度不与其他列的高度协调的问题

### 0.2.3

`2016-08-30`

- 修复带多选的 Table 在数据更新后无法选中的问题
- 修复 Input-Number 的小数计算问题
- Checkbox `label` 的值不再限定只能是 string 类型，可以是 object 或者 number

### 0.2.2

`2016-08-08`

- input-number 无法直接修改值的问题
- 修复 DatePicker 在 Form 中的显示问题
- 修复可清空的单选 Select 在点击清空按钮后 value 值不变的问题
- 为 Switch 添加 change 事件，在其值改变时触发
- 为 TableColumn 添加 show-tooltip-when-overflow 属性
- 修复 menu 的 activeKey 绑定值直接改变后无法触发菜单激活的问题

### 0.2.1

`2016-07-29`

- 修复 Dialog 内容超出时无法显示的问题

### 0.2.0

`2016-07-29`

- 增加 grid 相关组件
- form-item 增加 required 属性
- dropdown 组件增加下拉菜单水平对齐方向的属性
- form 组件增加 label-align,label-width,label-suffix属性
- form 组件实例方法增加 validateField(prop, cb) 方法对单个表单项进行验证

*非兼容性更新*

- progress 的 percentage 属性值范围从 0～1 改变为 1~100.
- input,input-number,autocomplete,select,checkbox,radio 组件的 model 属性改为 value
- checkbox,radio 组件的 value 属性改为 label
- form 组件的 models 属性改为 model

### 0.1.9

`2016-07-12`

- 增加 menu 组件

*非兼容性更新*

- 使用了新的图标集，原有的某些图标可能不存在了

### 0.1.8

`2016-07-07`

- dropdown 和 tooltip 首次出现闪动问题

### 0.1.7

`2016-07-06`

- dropdown 增加触发下拉菜单方式的参数
- 修正若干组件的样式问题和浏览器兼容问题
- 修复 popper.js 产生的过多 scroll 事件绑定
- 在 radio-group 里增加 radio-button 类型
- 为 select 添加 singleCancelable 选项

### 0.1.6

`2016-06-30`
- dropdown-menu 改为动态创建
- 修复 textarea 缺失 model 参数的 bug
- 修复 pagination 和 input-group 在 safari 下的样式问题

### 0.1.5

`2016-06-29`
- 为 MessageBox 和 Notification 注册全局方法
- button 的 loading 状态时改为不触发 hover 和点击等操作
- input组件 增加 maxlength 和 minlength 属性支持

### 0.1.4

`2016-06-29`

- 增加 Tabs、Form、MessageBox、Alert、Notification、Slider 组件
- dropdown menu 现在是直接插入到 body 节点下，并且修正了自适应宽度的 bug
- dropdown item 点击后关闭 dropdown menu
- radio 绑定值增加 Number 类型支持
- 增加 radio-group 组件
- 增加 checkbox-group 组件
- Select 组件 API 更新，现在的用法和原生 select 标签更加相似
